@@ -41,8 +41,6 @@
 
 #define KCALENDARCORE_DECL_DEPRECATED_TEXT(text) __attribute__ ((__deprecated__(text)))
 
-#define ECM_GENERATEEXPORTHEADER_VERSION_VALUE(major, minor, patch) ((major<<16)|(minor<<8)|(patch))
-
 /* Take any defaults from group settings */
 #if !defined(KCALENDARCORE_NO_DEPRECATED) && !defined(KCALENDARCORE_DISABLE_DEPRECATED_BEFORE_AND_AT)
 #  ifdef KF_NO_DEPRECATED
@@ -86,7 +84,7 @@
 #define KCALENDARCORE_BUILD_DEPRECATED_SINCE(major, minor) 1
 
 #ifdef KCALENDARCORE_NO_DEPRECATED
-#  define KCALENDARCORE_DISABLE_DEPRECATED_BEFORE_AND_AT 0x56800
+#  define KCALENDARCORE_DISABLE_DEPRECATED_BEFORE_AND_AT 0x56a00
 #endif
 #ifdef KCALENDARCORE_NO_DEPRECATED_WARNINGS
 #  define KCALENDARCORE_DEPRECATED_WARNINGS_SINCE 0
@@ -96,7 +94,7 @@
 #  ifdef KCALENDARCORE_DISABLE_DEPRECATED_BEFORE_AND_AT
 #    define KCALENDARCORE_DEPRECATED_WARNINGS_SINCE KCALENDARCORE_DISABLE_DEPRECATED_BEFORE_AND_AT
 #  else
-#    define KCALENDARCORE_DEPRECATED_WARNINGS_SINCE 0x56800
+#    define KCALENDARCORE_DEPRECATED_WARNINGS_SINCE 0x56a00
 #  endif
 #endif
 
@@ -105,7 +103,7 @@
 #endif
 
 #ifdef KCALENDARCORE_DEPRECATED
-#  define KCALENDARCORE_ENABLE_DEPRECATED_SINCE(major, minor) (ECM_GENERATEEXPORTHEADER_VERSION_VALUE(major, minor, 0) > KCALENDARCORE_DISABLE_DEPRECATED_BEFORE_AND_AT)
+#  define KCALENDARCORE_ENABLE_DEPRECATED_SINCE(major, minor) (((major<<16)|(minor<<8)) > KCALENDARCORE_DISABLE_DEPRECATED_BEFORE_AND_AT)
 #else
 #  define KCALENDARCORE_ENABLE_DEPRECATED_SINCE(major, minor) 0
 #endif
@@ -145,6 +143,12 @@
 #else
 #  define KCALENDARCORE_DEPRECATED_VERSION_5_97(text)
 #endif
+
+#if KCALENDARCORE_DEPRECATED_WARNINGS_SINCE >= 0x56a00
+#  define KCALENDARCORE_DEPRECATED_VERSION_5_106(text) KCALENDARCORE_DECL_DEPRECATED_TEXT(text)
+#else
+#  define KCALENDARCORE_DEPRECATED_VERSION_5_106(text)
+#endif
 #define KCALENDARCORE_DEPRECATED_VERSION_5(minor, text)      KCALENDARCORE_DEPRECATED_VERSION_5_##minor(text)
 #define KCALENDARCORE_DEPRECATED_VERSION(major, minor, text) KCALENDARCORE_DEPRECATED_VERSION_##major(minor, "Since "#major"."#minor". " text)
 #define KCALENDARCORE_DEPRECATED_VERSION_BELATED(major, minor, textmajor, textminor, text) KCALENDARCORE_DEPRECATED_VERSION_##major(minor, "Since "#textmajor"."#textminor". " text)
